// Vertex shader
struct VertexInput {
    // position and color attributes
    @location(0) position: vec3<f32>, // Position in 3D space
    @location(1) color: vec3<f32>, // Color attribute
}

struct VertexOutput {
    @builtin(position) clip_position: vec4<f32>, // Clip space position
    @location(0) color: vec3<f32>, // Color output
}

struct Uniforms {
    transform: mat4x4<f32>, // Transformation matrix
}

@group(0) @binding(0)
var<uniform> uniforms: Uniforms;

@vertex
fn vs_main(model: VertexInput) -> VertexOutput {
    var out: VertexOutput; // Initialize output structure
    out.color = model.color; // Pass through color attribute
    out.clip_position = uniforms.transform * vec4<f32>(model.position, 1.0); // Transform position by the uniform matrix
    return out; 
}

// Fragment shader
@fragment
fn fs_main(in: VertexOutput) -> @location(0) vec4<f32> {
    return vec4<f32>(in.color, 1.0);
}